@@ -1,8 +1,9 @@
-"""Oaf provides a simple means of storing artifacts in OCI registries"""
+"""Oaf provides a dumb means of storing artifacts in OCI registries"""
 
 import pickle
 from enum import Enum
 import os
+import json
 import shutil
 import subprocess
 import tempfile
@@ -32,8 +33,22 @@ def push(
     obj_map: Optional[Dict[str, Any]] = None,
     obj_encoder: ObjEncoderType = ObjEncoderType.JSON_PICKLE,
     labels: Optional[Dict[str, str]] = None,
+    refs: Optional[Dict[str, str]] = None,
 ) -> None:
-    """Push data to registry"""
+    """Push data to repository
+
+    Args:
+        uri (str): URI of the repository
+        file (Optional[str  |  List[str]], optional): Filepath(s) to push. Defaults to None.
+        obj (Optional[Any  |  List[Any]], optional): Object(s) to push. Defaults to None.
+        obj_map (Optional[Dict[str, Any]], optional): Map of filename to object(s) to push. Defaults to None.
+        obj_encoder (ObjEncoderType, optional): Encoder to use for objects. Defaults to ObjEncoderType.JSON_PICKLE.
+        labels (Optional[Dict[str, str]], optional): Labels to add to the artifact. Defaults to None.
+        refs (Optional[Dict[str, str]], optional): Map of links to other related artifacts. Defaults to None.
+
+    Raises:
+        ValueError: If one of file, obj, or obj_map is not provided
+    """
 
     args = [
         BIN_PATHNAME,
@@ -96,6 +111,10 @@ def push(
             args.append("-l")
             args.append(f"{k}={v}")
 
+    if refs is not None:
+        args.append("-l")
+        args.append(f"refs={json.dumps(refs)}")
+
     try:
         subprocess.run(
             args=args,
@@ -112,7 +131,15 @@ def push(
 
 
 def pull(uri: str, out_path: str) -> List[str]:
-    """Pull files from registry"""
+    """Pull files from registry
+
+    Args:
+        uri (str): URI of artifact to pull
+        out_path (str): Directory to put files in
+
+    Returns:
+        List[str]: List of filepaths of artifacts
+    """
 
     args = [
         BIN_PATHNAME,
@@ -139,7 +166,14 @@ def pull(uri: str, out_path: str) -> List[str]:
 
 
 def pull_str(uri: str) -> Dict[str, str]:
-    """Pull files from registry as strings"""
+    """Pull files from registry as strings
+
+    Args:
+        uri (str): URI of the artifact
+
+    Returns:
+        Dict[str, str]: A map of filename to file text
+    """
     with tempfile.TemporaryDirectory() as out_path:
         args = [
             BIN_PATHNAME,
@@ -172,7 +206,14 @@ def pull_str(uri: str) -> Dict[str, str]:
 
 
 def pull_bytes(uri: str) -> Dict[str, bytes]:
-    """Pull files from registry as bytes"""
+    """Pull files from registry as bytes
+
+    Args:
+        uri (str): URI of the artifact
+
+    Returns:
+        Dict[str, bytes]: A map of filename to file bytes
+    """
     with tempfile.TemporaryDirectory() as out_path:
         args = [
             BIN_PATHNAME,
